"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AgentConfig = void 0;
const logger_1 = require("../logger");
class AgentConfig {
    constructor(initConfig, agentDependencies) {
        this.initConfig = initConfig;
        this.label = initConfig.label;
        this.logger = initConfig.logger ?? new logger_1.ConsoleLogger(logger_1.LogLevel.off);
        this.agentDependencies = agentDependencies;
    }
    /**
     * @todo move to context configuration
     */
    get walletConfig() {
        return this.initConfig.walletConfig;
    }
    get allowInsecureHttpUrls() {
        return this.initConfig.allowInsecureHttpUrls ?? false;
    }
    get autoUpdateStorageOnStartup() {
        return this.initConfig.autoUpdateStorageOnStartup ?? false;
    }
    get backupBeforeStorageUpdate() {
        return this.initConfig.backupBeforeStorageUpdate ?? true;
    }
    extend(config) {
        return new AgentConfig({ ...this.initConfig, logger: this.logger, label: this.label, ...config }, this.agentDependencies);
    }
    toJSON() {
        return {
            ...this.initConfig,
            walletConfig: {
                ...this.walletConfig,
                key: this.walletConfig?.key ? '[*****]' : undefined,
                storage: {
                    ...this.walletConfig?.storage,
                    credentials: this.walletConfig?.storage?.credentials ? '[*****]' : undefined,
                },
            },
            logger: this.logger.logLevel,
            agentDependencies: Boolean(this.agentDependencies),
            label: this.label,
        };
    }
}
exports.AgentConfig = AgentConfig;
//# sourceMappingURL=AgentConfig.js.map